@@ -24,7 +24,7 @@ class BitFieldCheckboxSelectMultiple(CheckboxSelectMultiple):
                 div *= 2
             value = real_value
         return super(BitFieldCheckboxSelectMultiple, self).render(
-            name, value, attrs=attrs, choices=enumerate(choices))
+            name, value, attrs=attrs)
 
     def _has_changed(self, initial, data):
         if initial is None:
@@ -44,7 +44,7 @@ class BitFormField(IntegerField):
         if isinstance(kwargs['initial'], int):
             iv = kwargs['initial']
             l = []
-            for i in range(0, 63):
+            for i in range(0, min(len(choices), 63)):
                 if (1 << i) & iv > 0:
                     l += [choices[i][0]]
             kwargs['initial'] = l
