@@ -1,7 +1,11 @@
+from __future__ import absolute_import
+
 from django import forms
-from bitfield.tests.models import BitFieldTestModel, CompositeBitFieldTestModel
+
+from bitfield.tests.models import BitFieldTestModel
+
 
 class BitFieldTestModelForm(forms.ModelForm):
-    
     class Meta:
         model = BitFieldTestModel
+        exclude = tuple()
